@@ -31,25 +31,30 @@ import socket
 from telnetlib import Telnet
 from typing import Any, Dict, List, Optional
 
-__version__ = '1.1.1'
-__all__ = ['PyNUT3Error', 'PyNUT3Client']
+__version__ = "1.2.1"
+__all__ = ["PyNUT3Error", "PyNUT3Client"]
 
 _LOGGER = logging.getLogger(__name__)
 
 
 class PyNUT3Error(Exception):
-    """Base class for custom exceptions.
-    """
+    """Base class for custom exceptions."""
 
 
 class PyNUT3Client:
     """Access NUT (Network UPS Tools) servers."""
 
     # pylint: disable=too-many-instance-attributes
-    def __init__(self, host: str = '127.0.0.1', port: int = 3493,
-                 login: Optional[str] = None, password: Optional[str] = None,
-                 timeout: float = 5, persistent: bool = True,
-                 debug: bool = True) -> None:
+    def __init__(
+        self,
+        host: str = "127.0.0.1",
+        port: int = 3493,
+        login: Optional[str] = None,
+        password: Optional[str] = None,
+        timeout: float = 5,
+        persistent: bool = True,
+        debug: bool = True,
+    ) -> None:
         """Class initialization method.
 
         host        : Host to connect (defaults to 127.0.0.1).
@@ -65,7 +70,9 @@ class PyNUT3Client:
         debug       : Boolean, put class in debug mode (prints everything
                         on console, defaults to False).
         """
-        _LOGGER.debug(f'NUT Class initialization, Host/Port: {host}:{port}, Login: {login}')
+        _LOGGER.debug(
+            f"NUT Class initialization, Host/Port: {host}:{port}, Login: {login}"
+        )
 
         self._debug = debug
         self._host: str = host
@@ -81,20 +88,20 @@ class PyNUT3Client:
 
     def __del__(self) -> None:
         """Try to disconnect cleanly when class is deleted."""
-        _LOGGER.debug('NUT Class deleted, trying to disconnect.')
+        _LOGGER.debug("NUT Class deleted, trying to disconnect.")
         self._disconnect()
 
-    def __enter__(self) -> 'PyNUT3Client':
+    def __enter__(self) -> "PyNUT3Client":
         return self
 
     def __exit__(self, exc_t: type, exc_v: IndexError, trace: Any) -> None:
         self.__del__()
 
     def _disconnect(self) -> None:
-        """ Disconnects from the defined server."""
+        """Disconnects from the defined server."""
         if self._srv_handler:
             try:
-                self._write('LOGOUT\n')
+                self._write("LOGOUT\n")
                 self._srv_handler.close()
             except (socket.error, AttributeError):
                 # The socket is already disconnected.
@@ -111,48 +118,50 @@ class PyNUT3Client:
 
             result: str
             if self._login is not None:
-                self._write(f'USERNAME {self._login}\n')
-                result = self._read_until('\n')
-                if result != 'OK\n':
-                    raise PyNUT3Error(result.replace('\n', ''))
+                self._write(f"USERNAME {self._login}\n")
+                result = self._read_until("\n")
+                if result != "OK\n":
+                    raise PyNUT3Error(result.replace("\n", ""))
 
             if self._password is not None:
-                self._write(f'PASSWORD {self._password}\n')
-                result = self._read_until('\n')
-                if result != 'OK\n':
-                    raise PyNUT3Error(result.replace('\n', ''))
+                self._write(f"PASSWORD {self._password}\n")
+                result = self._read_until("\n")
+                if result != "OK\n":
+                    raise PyNUT3Error(result.replace("\n", ""))
         except socket.error as exc:
-            raise PyNUT3Error('Socket error.') from exc
+            raise PyNUT3Error("Socket error.") from exc
 
     def _read_until(self, string: str) -> str:
-        """ Wrapper for _srv_handler read_until method."""
+        """Wrapper for _srv_handler read_until method."""
         try:
             if self._srv_handler is None:
-                raise RuntimeError('NUT3 connection has not been opened.')
-            return self._srv_handler.read_until(string.encode('ascii'), self._timeout).decode()
+                raise RuntimeError("NUT3 connection has not been opened.")
+            return self._srv_handler.read_until(
+                string.encode("ascii"), self._timeout
+            ).decode()
         except (EOFError, BrokenPipeError):
-            _LOGGER.error('NUT3 problem reading from server.')
-            return ''
+            _LOGGER.error("NUT3 problem reading from server.")
+            return ""
 
     def _write(self, string: str) -> None:
-        """ Wrapper for _srv_handler write method."""
+        """Wrapper for _srv_handler write method."""
         try:
             if self._srv_handler is None:
-                raise RuntimeError('NUT3 connection has not been opened.')
-            self._srv_handler.write(string.encode('ascii'))
+                raise RuntimeError("NUT3 connection has not been opened.")
+            self._srv_handler.write(string.encode("ascii"))
             return
         except (EOFError, BrokenPipeError):
-            _LOGGER.error('NUT3 problem writing to server.')
+            _LOGGER.error("NUT3 problem writing to server.")
 
     def description(self, ups: str) -> str:
         """Returns the description for a given UPS."""
-        _LOGGER.debug(f'NUT3 requesting description from server {self._host}')
+        _LOGGER.debug(f"NUT3 requesting description from server {self._host}")
 
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET UPSDESC {ups}\n')
-        result: str = self._read_until('\n')
+        self._write(f"GET UPSDESC {ups}\n")
+        result: str = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
@@ -160,7 +169,7 @@ class PyNUT3Client:
         try:
             return result.split('"')[1].strip()
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def get_dict_ups(self) -> Dict[str, str]:
         """Returns the list of available UPS from the NUT server.
@@ -168,23 +177,23 @@ class PyNUT3Client:
         The result is a dictionary containing 'key->val' pairs of
         'UPSName' and 'UPS Description'.
         """
-        _LOGGER.debug(f'NUT3 requesting list_ups from server {self._host}')
+        _LOGGER.debug(f"NUT3 requesting list_ups from server {self._host}")
 
         if not self._persistent:
             self._connect()
 
-        self._write('LIST UPS\n')
-        result: str = self._read_until('\n')
-        if result != 'BEGIN LIST UPS\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write("LIST UPS\n")
+        result: str = self._read_until("\n")
+        if result != "BEGIN LIST UPS\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until('END LIST UPS\n')
+        result = self._read_until("END LIST UPS\n")
 
         ups_dict: Dict[str, str] = {}
         line: str
-        for line in result.split('\n'):
-            if line.startswith('UPS'):
-                line = line[len('UPS '):-len('"')]
+        for line in result.split("\n"):
+            if line.startswith("UPS"):
+                line = line[len("UPS ") : -len('"')]
                 if '"' not in line:
                     continue
                 ups: str
@@ -208,18 +217,18 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'LIST VAR {ups}\n')
-        result: str = self._read_until('\n')
-        if result != f'BEGIN LIST VAR {ups}\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write(f"LIST VAR {ups}\n")
+        result: str = self._read_until("\n")
+        if result != f"BEGIN LIST VAR {ups}\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until(f'END LIST VAR {ups}\n')
-        offset: int = len(f'VAR {ups} ')
-        end_offset: int = 0 - (len(f'END LIST VAR {ups}\n') + 1)
+        result = self._read_until(f"END LIST VAR {ups}\n")
+        offset: int = len(f"VAR {ups} ")
+        end_offset: int = 0 - (len(f"END LIST VAR {ups}\n") + 1)
 
         ups_vars: Dict[str, str] = {}
         current: str
-        for current in result[:end_offset].split('\n'):
+        for current in result[:end_offset].split("\n"):
             current = current[offset:]
             if '"' not in current:
                 continue
@@ -244,26 +253,26 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'LIST CMD {ups}\n')
-        result: str = self._read_until('\n')
-        if result != f'BEGIN LIST CMD {ups}\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write(f"LIST CMD {ups}\n")
+        result: str = self._read_until("\n")
+        if result != f"BEGIN LIST CMD {ups}\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until(f'END LIST CMD {ups}\n')
-        offset: int = len(f'CMD {ups} ')
-        end_offset: int = 0 - (len(f'END LIST CMD {ups}\n') + 1)
+        result = self._read_until(f"END LIST CMD {ups}\n")
+        offset: int = len(f"CMD {ups} ")
+        end_offset: int = 0 - (len(f"END LIST CMD {ups}\n") + 1)
 
         commands: Dict[str, str] = {}
         current: str
-        for current in result[:end_offset].split('\n'):
+        for current in result[:end_offset].split("\n"):
             command: str = current[offset:].split('"')[0].strip()
 
             # For each var we try to get the available description
             try:
-                self._write(f'GET CMDDESC {ups} {command}\n')
-                temp: str = self._read_until('\n')
-                if temp.startswith('CMDDESC'):
-                    desc_offset = len(f'CMDDESC {ups} {command} ')
+                self._write(f"GET CMDDESC {ups} {command}\n")
+                temp: str = self._read_until("\n")
+                if temp.startswith("CMDDESC"):
+                    desc_offset = len(f"CMDDESC {ups} {command} ")
                     temp = temp[desc_offset:-1]
                     if '"' not in temp:
                         continue
@@ -278,7 +287,7 @@ class PyNUT3Client:
 
         return commands
 
-    def get_dict_clients(self, ups: str = '') -> Dict[str, List[str]]:
+    def get_dict_clients(self, ups: str = "") -> Dict[str, List[str]]:
         """Returns the list of connected clients from the NUT server.
 
         The result is a dictionary containing 'key->val' pairs of
@@ -290,27 +299,27 @@ class PyNUT3Client:
             self._connect()
 
         if ups and (ups not in self.get_dict_ups()):
-            raise PyNUT3Error(f'{ups} is not a valid UPS')
+            raise PyNUT3Error(f"{ups} is not a valid UPS")
 
         if ups:
-            self._write(f'LIST CLIENTS {ups}\n')
+            self._write(f"LIST CLIENTS {ups}\n")
         else:
-            self._write('LIST CLIENTS\n')
-        result = self._read_until('\n')
-        if result != 'BEGIN LIST CLIENTS\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+            self._write("LIST CLIENTS\n")
+        result = self._read_until("\n")
+        if result != "BEGIN LIST CLIENTS\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until('END LIST CLIENTS\n')
+        result = self._read_until("END LIST CLIENTS\n")
 
         clients: Dict[str, List[str]] = {}
         line: str
-        for line in result.split('\n'):
-            if line.startswith('CLIENT') and ' ' in line[len('CLIENT '):]:
-                line = line[len('CLIENT '):]
-                if ' ' not in line:
+        for line in result.split("\n"):
+            if line.startswith("CLIENT") and " " in line[len("CLIENT ") :]:
+                line = line[len("CLIENT ") :]
+                if " " not in line:
                     continue
                 host: str
-                host, ups = line.split(' ')[:2]
+                host, ups = line.split(" ")[:2]
                 if ups not in clients:
                     clients[ups] = []
                 clients[ups].append(host)
@@ -331,17 +340,17 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'LIST RW {ups}\n')
-        result: str = self._read_until('\n')
-        if result != f'BEGIN LIST RW {ups}\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write(f"LIST RW {ups}\n")
+        result: str = self._read_until("\n")
+        if result != f"BEGIN LIST RW {ups}\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until(f'END LIST RW {ups}\n')
-        offset: int = len(f'VAR {ups}')
-        end_offset: int = 0 - (len(f'END LIST RW {ups}\n') + 1)
+        result = self._read_until(f"END LIST RW {ups}\n")
+        offset: int = len(f"VAR {ups}")
+        end_offset: int = 0 - (len(f"END LIST RW {ups}\n") + 1)
 
         rw_vars: Dict[str, str] = {}
-        for current in result[:end_offset].split('\n'):
+        for current in result[:end_offset].split("\n"):
             current = current[offset:]
             if '"' not in current:
                 continue
@@ -365,24 +374,26 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'LIST ENUM {ups} {var}\n')
-        result: str = self._read_until('\n')
-        if result != f'BEGIN LIST ENUM {ups} {var}\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write(f"LIST ENUM {ups} {var}\n")
+        result: str = self._read_until("\n")
+        if result != f"BEGIN LIST ENUM {ups} {var}\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until(f'END LIST ENUM {ups} {var}\n')
-        offset: int = len(f'ENUM {ups} {var}')
-        end_offset: int = 0 - (len(f'END LIST ENUM {ups} {var}\n') + 1)
+        result = self._read_until(f"END LIST ENUM {ups} {var}\n")
+        offset: int = len(f"ENUM {ups} {var}")
+        end_offset: int = 0 - (len(f"END LIST ENUM {ups} {var}\n") + 1)
 
         if not self._persistent:
             self._disconnect()
 
         try:
-            return [c[offset:].split('"')[1].strip()
-                    for c in result[:end_offset].split('\n')
-                    if '"' in c[offset:]]
+            return [
+                c[offset:].split('"')[1].strip()
+                for c in result[:end_offset].split("\n")
+                if '"' in c[offset:]
+            ]
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def list_range(self, ups: str, var: str) -> List[str]:
         """Get a list of valid values for an range variable.
@@ -394,24 +405,26 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'LIST RANGE {ups} {var}\n')
-        result: str = self._read_until('\n')
-        if result != f'BEGIN LIST RANGE {ups} {var}\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        self._write(f"LIST RANGE {ups} {var}\n")
+        result: str = self._read_until("\n")
+        if result != f"BEGIN LIST RANGE {ups} {var}\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
-        result = self._read_until(f'END LIST RANGE {ups} {var}\n')
-        offset: int = len(f'RANGE {ups} {var}')
-        end_offset: int = 0 - (len(f'END LIST RANGE {ups} {var}\n') + 1)
+        result = self._read_until(f"END LIST RANGE {ups} {var}\n")
+        offset: int = len(f"RANGE {ups} {var}")
+        end_offset: int = 0 - (len(f"END LIST RANGE {ups} {var}\n") + 1)
 
         if not self._persistent:
             self._disconnect()
 
         try:
-            return [c[offset:].split('"')[1].strip()
-                    for c in result[:end_offset].split('\n')
-                    if '"' in c[offset:]]
+            return [
+                c[offset:].split('"')[1].strip()
+                for c in result[:end_offset].split("\n")
+                if '"' in c[offset:]
+            ]
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def set_var(self, ups: str, var: str, value: str) -> None:
         """Set a variable to the specified value on selected UPS.
@@ -424,11 +437,11 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'SET VAR {ups} {var} {value}\n')
-        result = self._read_until('\n')
+        self._write(f"SET VAR {ups} {var} {value}\n")
+        result = self._read_until("\n")
 
-        if result != 'OK\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        if result != "OK\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
         if not self._persistent:
             self._disconnect()
@@ -440,8 +453,8 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET VAR {ups} {var}\n')
-        result = self._read_until('\n')
+        self._write(f"GET VAR {ups} {var}\n")
+        result = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
@@ -449,7 +462,7 @@ class PyNUT3Client:
         try:
             return result.split('"')[1].strip()
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     # Alias for convenience
     def get(self, ups: str, var: str) -> str:
@@ -463,8 +476,8 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET DESC {ups} {var}\n')
-        result = self._read_until('\n')
+        self._write(f"GET DESC {ups} {var}\n")
+        result = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
@@ -472,7 +485,7 @@ class PyNUT3Client:
         try:
             return result.split('"')[1].strip()
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def var_type(self, ups: str, var: str) -> str:
         """Get a variable's type."""
@@ -481,30 +494,32 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET TYPE {ups} {var}\n')
-        result: str = self._read_until('\n')
+        self._write(f"GET TYPE {ups} {var}\n")
+        result: str = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
 
         try:
-            type_: str = ' '.join(result.split(' ')[3:]).strip()
+            type_: str = " ".join(result.split(" ")[3:]).strip()
             # Ensure the response was valid.
             assert len(type_) > 0
-            assert result.startswith('TYPE')
+            assert result.startswith("TYPE")
             return type_
         except AssertionError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def command_description(self, ups: str, command: str) -> str:
         """Get a command's description."""
-        _LOGGER.debug(f"NUT3 requesting command_description '{command}' on '{self._host}'.")
+        _LOGGER.debug(
+            f"NUT3 requesting command_description '{command}' on '{self._host}'."
+        )
 
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET CMDDESC {ups} {command}\n')
-        result: str = self._read_until('\n')
+        self._write(f"GET CMDDESC {ups} {command}\n")
+        result: str = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
@@ -512,7 +527,7 @@ class PyNUT3Client:
         try:
             return result.split('"')[1].strip()
         except IndexError as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def run_command(self, ups: str, command: str) -> None:
         """Send a command to the specified UPS."""
@@ -521,11 +536,11 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'INSTCMD {ups} {command}\n')
-        result: str = self._read_until('\n')
+        self._write(f"INSTCMD {ups} {command}\n")
+        result: str = self._read_until("\n")
 
-        if result != 'OK\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        if result != "OK\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
         if not self._persistent:
             self._disconnect()
@@ -537,16 +552,16 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'MASTER {ups}\n')
-        result: str = self._read_until('\n')
-        if result != 'OK MASTER-GRANTED\n':
-            raise PyNUT3Error(('Master level functions are not available', ''))
+        self._write(f"MASTER {ups}\n")
+        result: str = self._read_until("\n")
+        if result != "OK MASTER-GRANTED\n":
+            raise PyNUT3Error(("Master level functions are not available", ""))
 
-        _LOGGER.debug('FSD called...')
-        self._write(f'FSD {ups}\n')
-        result = self._read_until('\n')
-        if result != 'OK FSD-SET\n':
-            raise PyNUT3Error(result.replace('\n', ''))
+        _LOGGER.debug("FSD called...")
+        self._write(f"FSD {ups}\n")
+        result = self._read_until("\n")
+        if result != "OK FSD-SET\n":
+            raise PyNUT3Error(result.replace("\n", ""))
 
         if not self._persistent:
             self._disconnect()
@@ -560,16 +575,16 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write(f'GET NUMLOGINS {ups}\n')
-        result: str = self._read_until('\n')
+        self._write(f"GET NUMLOGINS {ups}\n")
+        result: str = self._read_until("\n")
 
         if not self._persistent:
             self._disconnect()
 
         try:
-            return int(result.split(' ')[2].strip())
+            return int(result.split(" ")[2].strip())
         except (ValueError, IndexError) as exc:
-            raise PyNUT3Error(result.replace('\n', '')) from exc
+            raise PyNUT3Error(result.replace("\n", "")) from exc
 
     def help(self) -> str:
         """Send HELP command."""
@@ -578,12 +593,12 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write('HELP\n')
+        self._write("HELP\n")
 
         if not self._persistent:
             self._disconnect()
 
-        return self._read_until('\n')
+        return self._read_until("\n")
 
     def ver(self) -> str:
         """Send VER command."""
@@ -592,9 +607,9 @@ class PyNUT3Client:
         if not self._persistent:
             self._connect()
 
-        self._write('VER\n')
+        self._write("VER\n")
 
         if not self._persistent:
             self._disconnect()
 
-        return self._read_until('\n')
+        return self._read_until("\n")
